@@ -1241,21 +1241,16 @@ class Experimento:
         elif grafica == 'regresion_lineal':
             print("Entro a regresión lineal")
 
-            if arreglo_series_tiempo == None:
-                print("No se ha seleccionado un arreglo a procesar")
+            indices_tiempo, series_tiempo = st.generar_series_tiempo(lista_a_procesar= arreglo_series_tiempo,
+                                                                     brinco_temporal=brincos_series_tiempo,
+                                                                     longitud_ventana_tiempo=longitud_series_tiempo)
 
-            else:
+            resultados = st.generar_regresion_lineal_para_series_tiempo(indices_tiempo=indices_tiempo,
+                                                                        series_tiempo=series_tiempo)
 
-                indices_tiempo, series_tiempo = st.generar_series_tiempo(lista_a_procesar= arreglo_series_tiempo,
-                                                                         brinco_temporal=brinco_temporal,
-                                                                         longitud_ventana_tiempo=longitud_series_tiempo)
-
-                resultados = st.generar_regresion_lineal_para_series_tiempo(indices_tiempo=indices_tiempo,
-                                                                            series_tiempo=series_tiempo)
-
-                for indice in range(0, len(indices_tiempo)):
-                    plt.scatter(indices_tiempo[indice], series_tiempo[indice], color='blue')
-                    plt.plot(indices_tiempo[indice], resultados[indice], color='red')
+            for indice in range(0, len(indices_tiempo)):
+                plt.scatter(indices_tiempo[indice], series_tiempo[indice], color='blue')
+                plt.plot(indices_tiempo[indice], resultados[indice], color='red')
 
         elif grafica == 'cilindros_objetos_importantes':
             print("Entro a volumenes_objetos_importantes")
